<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="gl" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Sobre</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Iniciar o torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Saltar a comprobación hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Crear subcartafol</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modo de xestión dos torrents:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sen categoría</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Engadir categoría...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Eliminar categoría</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Eliminar as categorías sen usar</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Continuar os torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Deter os torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Eliminar os torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova categoría</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editar categoría...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Saír do qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Só unha ligazón por liña</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>O límite da velocidade global de envío debe ser superior a 0 ou non funcionará.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>O límite da velocidade global de descarga debe ser ser superior a 0 ou non funcionará.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>O límite alternativo da velocidade de envío debe ser superior a 0 ou non funcionará.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>O límite alternativo da velocidade de descarga debe ser superior a 0 ou non funcionará.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>As descargas activas máximas deben ser superiores a -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Os envíos activos máximos deben ser superiores a -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Os torrents activos máximos deben ser superiores a -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>O límite do número máximo de conexións ten que ser superior a 0 ou debe desactivalo.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>O límite do número máximo de conexións por torrent ten que ser superior a 0 ou debe desactivalo.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>O límite do número máximo de slots de envío por torrent ten que ser superior a 0 ou debe desactivalo.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Non foi posíbel gardar as preferencias do programa, probabelmente o qBittorrent estea inaccesíbel.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent en Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>O límite da taxa de compartición debe estar entre 0 e 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>O límite do tempo de sementeira debe estar entre 0 e 525600 minutos.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>O porto usado para as conexións entrantes debe estar entre 1 e 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>O porto usado para a interface web debe estar entre 1 e 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Non é posíbel iniciar sesión. Probabelmente o qBittorrent non está accesíbel.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>O usuario ou o contrasinal son incorrectos.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome do usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autores orixinais</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Enviar torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Gardar os ficheiros na localización:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Escribir o cartafol aquí</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Máis información</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Información dos certificados</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Estabelecer a localización</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Límite da velocidade de envío</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Límite da velocidade de descarga</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Renomear torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Outra...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Luns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mércores</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Xoves</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Venres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Saír da sesión</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Descargar os torrents desde as URL ou ligazóns Magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Enviar torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Está seguro que desexa eliminar os torrents seleccionados da lista de transferencias?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>O cliente qBittorrent non está accesíbel</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Global number of upload slots limit must be greater than 0 or disabled.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nome de categoría incorrecto:
Non use caracteres especiais no nome da categoría.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Non é posíbel crear unha categoría</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>O límite da velocidade de envío ten que ser superior a 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espazo libre: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>O temporizador de inactividade do torrent debe ser maior de 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Xestión da gravación no disco</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>O límite da velocidade de descarga ten que ser superior a 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>O qBittorrent foi pechado.</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opcións...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra superior</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra de estado</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocidade na barra do título</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Doar!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Continuar todo</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausar todo</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Engadir un ficheiro torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentación</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Engadir ligazón torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Límite global de velocidade de envío</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Límite global de velocidade de descarga</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Confirma que desexa saír do qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, E: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Límites alternativos de velocidade</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Motor de busca</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrar a lista de torrents...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferencias</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexión</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interface web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Idioma da interface do usuario:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Enviar unha notificación por correo-e ao rematar a descarga</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Executar un programa externo ao rematar o torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrado de IPs</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Programar o uso de límites alternativos de velocidade</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Cola de torrents</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Engadir automaticamente estes localizadores ás novas descargas:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interface de usuario web (control remoto)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Enderezo IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Dominios do servidor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Usar HTTPS no canto de HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Omitir autenticación para clientes no servidor local</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Omitir a autenticación para clientes nas subredes con IP incluídas na lista branca</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Actualizar o nome do dominio dinámico</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Manter os torrents incompletos en:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copiar os ficheiros torrent a:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copiar os ficheiros torrent das descargas rematadas a:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pre-asignar o espazo no disco a todos os ficheiros</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Anexar a extensión !qB aos nomes dos ficheiros incompletos</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Engadir automaticamente os torrents desde:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Este servidor require unha conexión segura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome do usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocolo activado:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP e μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Porto de escoita</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Porto usado para as conexións entrantes:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Usar un porto UPnP / NAT-PMP para reencamiñar desde o router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Usar un porto distinto en cada inicio</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Límites da conexión</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Número máximo de conexións por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Número máximo global de conexións:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Número máximo de slots de envío por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Número máximo global de slots de envío:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ningún)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porto:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Usar o proxy para conexións cos pares</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Usar o proxy só para torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Ruta do filtro (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Enderezos IP bloqueados manualmente...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplicar aos localizadores</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Límites globais de velocidade</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Enviar:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Descargar:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Límites alternativos de velocidade </translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>De:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>A:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Cando:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Todos os días</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Entresemana</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Fins de semana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Axustes dos límites de velocidade</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplicar os límites de velocidade ás sobrecargas do transporte</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplicar o límite de velocidade ao protocolo uTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Confidencialidade</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Activar o DHT (rede descentralizada) para encontrar máis pares</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Activar o intercambio de pares (PeX) para buscar máis pares</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Activar a busca de pares locais (LPD) para encontrar máis pares</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modo cifrado:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Precisa cifrado</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Desactivar o cifrado</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Activar o modo anónimo</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Descargas activas máximas:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Envíos activos máximos:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Torrents activos máximos:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Non ter en conta os torrents lentos nestes límites</translation>
    </message>
    <message>
        <source>then</source>
        <translation>despois</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Usar un porto UPnP / NAT-PMP para reencamiñar desde o router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificado:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Chave:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Rexistro</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nome do dominio:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parámetros aceptados (sensíbel ás maiúsc.)</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nome do torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Categoría</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: ruta ao contido (igual á ruta raíz pero para torrents de varios ficheiros)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: ruta raíz (ruta ao subcartafol do primeiro torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Ruta onde gardar</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Número de ficheiros</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Tamaño do torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Localizador actual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Consello: encapsule o parámetro entre comiñas para evitar cortar o texto nun espazo en branco (p.e: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>O nome de usuario da interface web debe ter polo menos 3 caracteres.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>O contrasinal da interface web debe ter polo menos 6 caracteres.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Activar a protección contra clics enganosos</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Activar a protección contra falsificacións de peticións entre sitios web (CSRF).</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Eliminar os ficheiros .torrent despois</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Límite da velocidade de descarga:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Límite da velocidade de envío:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Cambiar o contrasinal actual</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Usar a interface web alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Ruta de gardado predeterminada:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>A localización alternativa dos ficheiros da interface de usuario non pode quedar baleira.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Non iniciar a descarga automaticamente</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Cambiar o torrent a modo manual</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Cando a categoría do torrent cambiou:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Relocalizar os torrents afectados</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Aplicar o límite de velocidade aos pares da LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa sen límite</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Relocalizar torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Cando a ruta de gardado predeterminada cambiou:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Activar a validación da cabeceira do servidor</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguranza</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Cando a ruta de gardado da categoría cambiou:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Crear subcartafol para os torrents con varios ficheiros</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Cambiar os torrents afectados ao modo manual</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Localización dos ficheiros:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temporizador de inactividade do torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Modo de xestión de torrents predeterminado:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Cando engada un torrent</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>sec</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries (GeoIP):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listen on IPv6 address (requires restart):</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexión</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>V. de descarga</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>V. de envío</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Ficheiros</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>País</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Máxima</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Xeral</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Localizadores</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fontes HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contido</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Descargado:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferencia</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tempo  en activo:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Tempo restante:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Enviado:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Sementes:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocidade de descarga:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocidade de envío:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Pares:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Límite da descarga:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Límite do envío:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Desbotado:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Conexións:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Taxa de compartición:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Anunciar de novo en:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Visto completo por última vez:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Tamaño total:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Anacos:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creado por:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Engadido o:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Completado o:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creado o:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash do torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Ruta:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ten %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 nesta sesión)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 máx.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 media)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Límite da descarga:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Límite do envío:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Cartafol monitorizado</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Substituír a localización onde gardar</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Cartafol monitorizado</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Localización predeterminada onde gardar</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estadísticas de usuario</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estadísticas da caché</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Accesos á caché de lectura:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Tempo medio na cola:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Pares conectados:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Taxa de compartición total:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Descarga total:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Desbotado na sesión:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Envío total:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Tamaño total do búfer:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estadísticas de rendemento</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Traballos na cola E/S:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Sobrecarga da caché de escritura:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Sobrecarga da caché de lectura:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Tamaño total da cola:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nodos</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Todos (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Descargando (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Sementando (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Completados (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Comezados (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Detidos (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Activos (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactivos (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Con erros (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Todos (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Descargando (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Sementando (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Completados (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Detidos (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Comezados (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Activos (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactivos (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Con erros (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Sementes</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. de descarga</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. de envío</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Taxa</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Tempo restante</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Engadido o</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Completado o</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Localizador</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Límite de descarga</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Límite de envío</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Desc. na sesión</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Env. na sesión</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restante</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tempo  en activo</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Ruta onde gardar</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Límite da taxa</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Visto completo por última vez</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Última actividade</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Tamaño total</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensaxe</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL do localizador:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Funcionando</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Aínda sen contactar</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Sementes</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Non está funcionando</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copiar a url do localizador</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Engadir un novo localizador...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Editar URL do localizador</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Edición do localizador</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Samesugas</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Eliminar o localizador</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Diálogo de adición de localizadores</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista de localizadores a engadir (un por liña):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>Hai %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Asignando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Detido</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completados</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Movendo</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Sementando</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Sementando</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Na cola</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Con erros</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Descargando</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Descargando os metadatos</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Comprobando</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Ficheiros que faltan</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Na cola de comprobación</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Comprobando os datos de continuación</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Á espera</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Límites da velocidade de descarga do torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Límites da velocidade de envío do torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Cambiar o nome</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forzar continuación</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Límite da taxa de compartición...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Límite da velocidade de envío...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Límite da velocidade de descarga...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mover arriba</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mover abaixo</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mover ao principio</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mover ao final</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Estabelecer a localización...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Descargar primeiro os anacos inicial e final</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Xestión automática dos torrents</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nova...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Restabelecer</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forzar outra comprobación</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Modo super-sementeira</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Cambiar o nome...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Descargar en orde secuencial</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forzar outra comprobación</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova categoría</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nome novo</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Estabelecer a localización</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forzar outro anuncio</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editar categoría</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Gardar a ruta</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Límites da taxa de Envío/Descarga do torrent</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Usar o límite global de compartición</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Non estabelecer límite de compartición</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Estabelecer o límite de compartición en</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>taxa</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmación da eliminación</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Eliminar tamén os ficheiros do disco duro</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmación de eliminación - 'qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Descargar desde URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Engadir ligazóns ao torrent...</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>A ruta de gardado está baleira</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Ruta do engadido:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL ou cartafol local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalar engadido</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Sementes:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Todos os engadidos</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Engadidos de busca...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Todas as categorías</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Buscar en:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultados (mostrando</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Só nos nomes dos torrents</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Só activados</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>de</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>En todo</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalar engadido novo</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Pode obter novos engadidos de busca aquí:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Engadidos de busca instalados:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activados</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Aviso: asegúrese de cumprir as leis sobre dereitos de autor do seu país cando descargue torrents con calquera destes motores de busca.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Buscar actualizacións</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Engadidos de busca</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Pares incompletos</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de busca</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Sementadores</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activado</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tag:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Current maintainer</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Special Thanks</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Libraries</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>